@@ -16,33 +16,35 @@ class bcolors:
 def filechecker(FILENAME):
     if os.path.isfile(FILENAME):
         print(bcolors.OKGREEN + "%s file is created" % FILENAME + bcolors.ENDC)
-        time.sleep(0.5)
     else: 
         print(bcolors.FAIL + "%s file is not created, please try again" % FILENAME + bcolors.ENDC)
-        time.sleep(0.5)
-        sys.exit(1)
-        
+    time.sleep(0.5)
+
 
 
 def folderchecker(FOLDERNAME):
     if os.path.isdir(FOLDERNAME):
         print(bcolors.OKGREEN + "%s is created with a proper content" % FOLDERNAME + bcolors.ENDC)
-        time.sleep(0.5)
     else: 
         print(bcolors.FAIL + "%s is not created with a proper content, please try again" %FOLDERNAME + bcolors.ENDC)
-        time.sleep(0.5)
-        sys.exit(1)
-
+    time.sleep(0.5)
 
 
 def sizechecker(FILENAME):
     if os.path.getsize(FILENAME) <= 0:
-        print(bcolors.FAIL + FILENAME + " seems to be empty" + bcolors.ENDC  )
-        time.sleep(0.5)
+        print(bcolors.FAIL + "%s"  + " seems to be empty" % FILENAME + bcolors.ENDC  )
     else:
-        print(bcolors.FAIL +  "Something went wrong please try again" + bcolors.ENDC)
-        time.sleep(0.5)
-        sys.exit(1)
+        print(bcolors.OKGREEN + "The file is not empty" + bcolors.ENDC) 
+    time.sleep(0.5)
+
+
+
+def linechecker(FILENAME):
+    num_lines = sum(1 for line in open(FILENAME))
+    sizechecker(FILENAME)
+    if os.path.isfile(FILENAME) and num_lines == 10:
+        print(bcolors.OKGREEN + FILENAME + " has been created and has %d lines" % num_lines + bcolors.ENDC)
+    else:
+        print(bcolors.FAIL +  FILENAME + " has not been created or has %d lines" % num_lines + bcolors.ENDC)
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
 
-
